@@ -6,13 +6,9 @@ use strict;
 use warnings;
 
 use Carp;
-use Exporter;
+use Exporter qw{ import };
 
-# Beause the Perl 5.6 Exporter does not export import().
-BEGIN {
-    *import	= \&Exporter::import;
-}
-our $VERSION = '0.022_01';
+our $VERSION = '0.005';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -148,9 +144,7 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -158,7 +152,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
