@@ -11,7 +11,7 @@ use PPI::Dumper;
 use PPIx::QuoteLike;
 use Scalar::Util ();
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 {
     my $default = {
@@ -53,9 +53,11 @@ our $VERSION = '0.004';
 sub dump : method {	## no critic (ProhibitBuiltinHomonyms)
     my ( $class, $source, %arg ) = @_;
     my $rslt;
+    my $margin = ' ' x ( $arg{margin} || 0 );
+    my $none = delete $arg{none};
     foreach my $obj ( $class->_source_to_dumpers( $source, %arg ) ) {
 	my $src = $obj->{object}->source();
-	$rslt .= "\n$src";
+	$rslt .= "\n$margin$src";
 	if ( _isa( $src, 'PPI::Element' ) and my $loc = $src->location() ) {
 	    $rslt .= sprintf ' %s line %d column %d',
 		_dor( $loc->[4], $obj->{file}, '?' ),
@@ -65,7 +67,10 @@ sub dump : method {	## no critic (ProhibitBuiltinHomonyms)
     }
     defined $rslt
 	and return $rslt;
-    return;
+    defined $none
+	or return;
+    $none =~ s/ (?: \A | (?<! \n ) ) \z /\n/smx;
+    return $none;
 }
 
 sub list {
@@ -88,13 +93,16 @@ sub list {
 	    qw{ type start finish };
 	push @rslt,
 	    join "\t", ref $obj, $string,
-	    _format_attr( $obj, qw{ failures interpolates } ),
+	    _format_attr( $obj, qw{ encoding failures interpolates } ),
 	    $self->_perl_version( $obj ),
 	    $self->_variables( $obj ),
 	    ;
 	$selector = sub { return $obj->children() };
     }
     foreach my $elem ( $selector->() ) {
+	$self->{significant}
+	    and not $elem->significant()
+	    and next;
 	my @line = (
 	    ref $elem,
 	    _quote( $elem->content() ),
@@ -407,6 +415,22 @@ L<PPI::Node|PPI::Node>.
 Otherwise the first argument is handled just like L<new()|/new> would
 handle it.
 
+The return is the string representation of the dump.
+
+In addition to the optional arguments accepted by L<new()|/new>, the
+following can be specified:
+
+=over
+
+=item none
+
+This argument specifies a string to return if no dump can be produced
+(typically because the first argument is neither a file name nor text
+that is recognized by this package). If unspecified, or specified as
+C<undef>, nothing is returned in this case.
+
+=back 
+
 The output for an individual quote-like object differs from the
 L<string()|/string> output on the same object in that it is preceded by
 the literal sting being dumped, and file and location information if
